import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrInputBase } from "./igr-input-base";
import { Input } from "./Input";
import { IgcInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**

*/
export class IgrInput extends IgrInputBase {
    createImplementation() {
        return new Input();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._change = null;
        this._change_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The value of the control.
    */
    get value() {
        return this.i.am;
    }
    set value(v) {
        this.i.am = v;
    }
    /**
     * The type attribute of the control.
    */
    get type() {
        return this.i.ab;
    }
    set type(v) {
        this.i.ab = ensureEnum(InputType_$type, v);
    }
    /**
     * The input mode attribute of the control.
    */
    get inputmode() {
        return this.i.aa;
    }
    set inputmode(v) {
        this.i.aa = ensureEnum(InputInputmode_$type, v);
    }
    /**
     * The pattern attribute of the control.
    */
    get pattern() {
        return this.i.al;
    }
    set pattern(v) {
        this.i.al = v;
    }
    /**
     * Controls the validity of the control.
    */
    get invalid() {
        return this.i.ad;
    }
    set invalid(v) {
        this.i.ad = ensureBool(v);
    }
    /**
     * The minlength attribute of the control.
    */
    get minlength() {
        return this.i.af;
    }
    set minlength(v) {
        this.i.af = +v;
    }
    /**
     * The maxlength attribute of the control.
    */
    get maxlength() {
        return this.i.ae;
    }
    set maxlength(v) {
        this.i.ae = +v;
    }
    /**
     * The min attribute of the control.
    */
    get min() {
        return this.i.ak;
    }
    set min(v) {
        this.i.ak = v;
    }
    /**
     * The max attribute of the control.
    */
    get max() {
        return this.i.aj;
    }
    set max(v) {
        this.i.aj = v;
    }
    /**
     * The step attribute of the control.
    */
    get step() {
        return this.i.ag;
    }
    set step(v) {
        this.i.ag = +v;
    }
    /**
     * The autofocus attribute of the control.
    */
    get autofocus() {
        return this.i.ac;
    }
    set autofocus(v) {
        this.i.ac = ensureBool(v);
    }
    /**
     * The autocomplete attribute of the control.
    */
    get autocomplete() {
        return this.i.ai;
    }
    set autocomplete(v) {
        this.i.ai = v;
    }
    get tabIndex() {
        return this.i.ah;
    }
    set tabIndex(v) {
        this.i.ah = +v;
    }
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    reportValidity() {
        this.i.ap();
    }
    /**
     * Checks for validity of the control and emits the invalid event if it invalid.
    
    */
    checkValidity() {
        this.i.ao();
    }
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    setCustomValidity(message) {
        this.i.ar(message);
    }
    /**
     * Selects all text within the input.
    
    */
    select() {
        this.i.aq();
    }
    /**
     * Increments the numeric value of the input by one or more steps.
    
    */
    stepUp(n) {
        this.i.at(n);
    }
    /**
     * Decrements the numeric value of the input by one or more steps.
    
    */
    stepDown(n) {
        this.i.as(n);
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrComponentValueChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
        if (this.i.changeChanged) {
            this.i.changeChanged();
        }
        ;
    }
}
