import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { SelectDir_$type } from "./SelectDir";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { IgrDropdown } from "./igr-dropdown";
import { Select } from "./Select";
import { IgcSelectComponent, defineComponents } from "igniteui-webcomponents";
import { ensureBool, ensureEnum } from "igniteui-react-core";
export class IgrSelect extends IgrDropdown {
    createImplementation() {
        return new Select();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._focus = null;
        this._focus_wrapped = null;
        this._blur = null;
        this._blur_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcSelectComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-select", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The value attribute of the control.
    */
    get value() {
        return this.i.ak;
    }
    set value(v) {
        this.i.ak = v;
    }
    /**
     * The name attribute of the control.
    */
    get name() {
        return this.i.ai;
    }
    set name(v) {
        this.i.ai = v;
    }
    /**
     * The disabled attribute of the control.
    */
    get disabled() {
        return this.i.ad;
    }
    set disabled(v) {
        this.i.ad = ensureBool(v);
    }
    /**
     * The required attribute of the control.
    */
    get required() {
        return this.i.ag;
    }
    set required(v) {
        this.i.ag = ensureBool(v);
    }
    /**
     * The invalid attribute of the control.
    */
    get invalid() {
        return this.i.ae;
    }
    set invalid(v) {
        this.i.ae = ensureBool(v);
    }
    /**
     * The outlined attribute of the control.
    */
    get outlined() {
        return this.i.af;
    }
    set outlined(v) {
        this.i.af = ensureBool(v);
    }
    /**
     * The autofocus attribute of the control.
    */
    get autofocus() {
        return this.i.ac;
    }
    set autofocus(v) {
        this.i.ac = ensureBool(v);
    }
    /**
     * The label attribute of the control.
    */
    get label() {
        return this.i.ah;
    }
    set label(v) {
        this.i.ah = v;
    }
    /**
     * The placeholder attribute of the control.
    */
    get placeholder() {
        return this.i.aj;
    }
    set placeholder(v) {
        this.i.aj = v;
    }
    /**
     * The direction attribute of the control.
    */
    get dir() {
        return this.i.z;
    }
    set dir(v) {
        this.i.z = ensureEnum(SelectDir_$type, v);
    }
    /**
     * Sets focus on the component.
    
    */
    focusComponent(options) {
        this.i.ap((options == null ? null : options.i));
    }
    /**
     * Removes focus from the component.
    
    */
    blurComponent() {
        this.i.am();
    }
    /**
     * Checks the validity of the control and moves the focus to it if it is not valid.
    
    */
    reportValidity() {
        this.i.aq();
    }
    /**
     * Checks the validity of the control.
    
    */
    checkValidity() {
        this.i.an();
    }
    get focus() {
        return this._focus;
    }
    set focus(ev) {
        if (this._focus_wrapped !== null) {
            this.i.focus = delegateRemove(this.i.focus, this._focus_wrapped);
            this._focus_wrapped = null;
            this._focus = null;
        }
        this._focus = ev;
        this._focus_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeFocus) {
                this.beforeFocus(this, outerArgs);
            }
            if (this._focus) {
                this._focus(this, outerArgs);
            }
        };
        this.i.focus = delegateCombine(this.i.focus, this._focus_wrapped);
        if (this.i.focusChanged) {
            this.i.focusChanged();
        }
        ;
    }
    get blur() {
        return this._blur;
    }
    set blur(ev) {
        if (this._blur_wrapped !== null) {
            this.i.blur = delegateRemove(this.i.blur, this._blur_wrapped);
            this._blur_wrapped = null;
            this._blur = null;
        }
        this._blur = ev;
        this._blur_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeBlur) {
                this.beforeBlur(this, outerArgs);
            }
            if (this._blur) {
                this._blur(this, outerArgs);
            }
        };
        this.i.blur = delegateCombine(this.i.blur, this._blur_wrapped);
        if (this.i.blurChanged) {
            this.i.blurChanged();
        }
        ;
    }
}
