import * as React from 'react';
import { StepStepType_$type } from "./StepStepType";
import { StepTitlePosition_$type } from "./StepTitlePosition";
import { StepOrientation_$type } from "./StepOrientation";
import { Step } from "./Step";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcStepComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * The step component is used within the `igc-stepper` element and it holds the content of each step.
 * It also supports custom indicators, title and subtitle.
*/
export class IgrStep extends React.Component {
    createImplementation() {
        return new Step();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcStepComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => this.setState({}));
        this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-step", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Gets/sets whether the step is invalid.
    */
    get invalid() {
        return this.i.j;
    }
    set invalid(v) {
        this.i.j = ensureBool(v);
    }
    /**
     * Gets/sets whether the step is activе.
    */
    get active() {
        return this.i.f;
    }
    set active(v) {
        this.i.f = ensureBool(v);
    }
    /**
     * Gets/sets whether the step is optional.
     * @remarks
     * Optional steps validity does not affect the default behavior when the stepper is in linear mode i.e.
     * if optional step is invalid the user could still move to the next step.
    */
    get optional() {
        return this.i.l;
    }
    set optional(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Gets/sets whether the step is interactable.
    */
    get disabled() {
        return this.i.i;
    }
    set disabled(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * Gets/sets whether the step is completed.
     * @remarks
     * When set to `true` the following separator is styled `solid`.
    */
    get complete() {
        return this.i.g;
    }
    set complete(v) {
        this.i.g = ensureBool(v);
    }
    /**
     * @private
    */
    get previousComplete() {
        return this.i.m;
    }
    set previousComplete(v) {
        this.i.m = ensureBool(v);
    }
    /**
     * @private
    */
    get stepType() {
        return this.i.b;
    }
    set stepType(v) {
        this.i.b = ensureEnum(StepStepType_$type, v);
    }
    /**
     * @private
    */
    get titlePosition() {
        return this.i.c;
    }
    set titlePosition(v) {
        this.i.c = ensureEnum(StepTitlePosition_$type, v);
    }
    /**
     * @private
    */
    get orientation() {
        return this.i.a;
    }
    set orientation(v) {
        this.i.a = ensureEnum(StepOrientation_$type, v);
    }
    /**
     * @private
    */
    get index() {
        return this.i.o;
    }
    set index(v) {
        this.i.o = +v;
    }
    /**
     * @private
    */
    get contentTop() {
        return this.i.h;
    }
    set contentTop(v) {
        this.i.h = ensureBool(v);
    }
    /**
     * @private
    */
    get linearDisabled() {
        return this.i.k;
    }
    set linearDisabled(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * @private
    */
    get visited() {
        return this.i.n;
    }
    set visited(v) {
        this.i.n = ensureBool(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Step");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
