import * as React from 'react';
import { CircularGradient } from "./CircularGradient";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * Used for defining gradient stops in the igc-circular-progress.
 * For each `igc-circular-gradient` defined as `gradient` slot of `igc-circular-progress` element would be created a SVG stop element.
 * The values passed as `color`, `offset` and `opacity` would be set as
 * `stop-color`, `offset` and `stop-opacity` of the SVG element without further validations.
*/
export declare class IgrCircularGradient<P extends IIgrCircularGradientProps = IIgrCircularGradientProps> extends React.Component<P, {}> {
    protected createImplementation(): CircularGradient;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): CircularGradient; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrCircularGradient;
    protected _renderer: ReactRenderer;
    protected _portalManager: PortalManager;
    private onImplementationCreated;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Defines where the gradient stop is placed along the gradient vector
    */
    get offset(): string;
    set offset(v: string);
    /**
     * Defines the color of the gradient stop
    */
    get color(): string;
    set color(v: string);
    /**
     * Defines the opacity of the gradient stop
    */
    get opacity(): number;
    set opacity(v: number);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    setNativeElement(element: any): void;
}
export interface IIgrCircularGradientProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Defines where the gradient stop is placed along the gradient vector
    */
    offset?: string;
    /**
     * Defines the color of the gradient stop
    */
    color?: string;
    /**
     * Defines the opacity of the gradient stop
    */
    opacity?: number | string;
}
