import * as React from 'react';
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { IgrSliderBase, IIgrSliderBaseProps } from "./igr-slider-base";
import { Slider } from "./Slider";
/**
 * A slider component used to select numeric value within a range.
*/
export declare class IgrSlider extends IgrSliderBase<IIgrSliderProps> {
    protected createImplementation(): Slider;
    /**
                                 * @hidden
                                 */
    get i(): Slider;
    constructor(props: IIgrSliderProps);
    componentDidMount(): void;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: string;
        style: {};
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    get value(): number;
    set value(v: number);
    get ariaLabel(): string;
    set ariaLabel(v: string);
    /**
     * Increments the value of the slider by `stepIncrement * step`, where `stepIncrement` defaults to 1.
     * stepIncrement Optional step increment. If no parameter is passed, it defaults to 1.
    
    * @param stepIncrement  * Optional step increment. If no parameter is passed, it defaults to 1.
    */
    stepUp(stepIncrement: number): void;
    /**
     * Decrements the value of the slider by `stepDecrement * step`, where `stepDecrement` defaults to 1.
     * stepDecrement Optional step decrement. If no parameter is passed, it defaults to 1.
    
    * @param stepDecrement  * Optional step decrement. If no parameter is passed, it defaults to 1.
    */
    stepDown(stepDecrement: number): void;
    private _input;
    private _input_wrapped;
    /**
     * Emitted when a value is changed via thumb drag or keyboard interaction.
    */
    get input(): (s: IgrSlider, e: IgrNumberEventArgs) => void;
    set input(ev: (s: IgrSlider, e: IgrNumberEventArgs) => void);
    private _change;
    private _change_wrapped;
    /**
     * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
    */
    get change(): (s: IgrSlider, e: IgrNumberEventArgs) => void;
    set change(ev: (s: IgrSlider, e: IgrNumberEventArgs) => void);
}
export interface IIgrSliderProps extends IIgrSliderBaseProps {
    value?: number | string;
    ariaLabel?: string;
    /**
     * Emitted when a value is changed via thumb drag or keyboard interaction.
    */
    input?: (s: IgrSlider, e: IgrNumberEventArgs) => void;
    /**
     * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
    */
    change?: (s: IgrSlider, e: IgrNumberEventArgs) => void;
}
