import * as React from 'react';
import { StepStepType } from "./StepStepType";
import { StepTitlePosition } from "./StepTitlePosition";
import { StepOrientation } from "./StepOrientation";
import { Step } from "./Step";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * The step component is used within the `igc-stepper` element and it holds the content of each step.
 * It also supports custom indicators, title and subtitle.
*/
export declare class IgrStep<P extends IIgrStepProps = IIgrStepProps> extends React.Component<P, {}> {
    protected createImplementation(): Step;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Step; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrStep;
    protected _renderer: ReactRenderer;
    protected _portalManager: PortalManager;
    private onImplementationCreated;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Gets/sets whether the step is invalid.
    */
    get invalid(): boolean;
    set invalid(v: boolean);
    /**
     * Gets/sets whether the step is activе.
    */
    get active(): boolean;
    set active(v: boolean);
    /**
     * Gets/sets whether the step is optional.
     * @remarks
     * Optional steps validity does not affect the default behavior when the stepper is in linear mode i.e.
     * if optional step is invalid the user could still move to the next step.
    */
    get optional(): boolean;
    set optional(v: boolean);
    /**
     * Gets/sets whether the step is interactable.
    */
    get disabled(): boolean;
    set disabled(v: boolean);
    /**
     * Gets/sets whether the step is completed.
     * @remarks
     * When set to `true` the following separator is styled `solid`.
    */
    get complete(): boolean;
    set complete(v: boolean);
    /**
     * @private
    */
    get previousComplete(): boolean;
    set previousComplete(v: boolean);
    /**
     * @private
    */
    get stepType(): StepStepType;
    set stepType(v: StepStepType);
    /**
     * @private
    */
    get titlePosition(): StepTitlePosition;
    set titlePosition(v: StepTitlePosition);
    /**
     * @private
    */
    get orientation(): StepOrientation;
    set orientation(v: StepOrientation);
    /**
     * @private
    */
    get index(): number;
    set index(v: number);
    /**
     * @private
    */
    get contentTop(): boolean;
    set contentTop(v: boolean);
    /**
     * @private
    */
    get linearDisabled(): boolean;
    set linearDisabled(v: boolean);
    /**
     * @private
    */
    get visited(): boolean;
    set visited(v: boolean);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    setNativeElement(element: any): void;
}
export interface IIgrStepProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Gets/sets whether the step is invalid.
    */
    invalid?: boolean | string;
    /**
     * Gets/sets whether the step is activе.
    */
    active?: boolean | string;
    /**
     * Gets/sets whether the step is optional.
     * @remarks
     * Optional steps validity does not affect the default behavior when the stepper is in linear mode i.e.
     * if optional step is invalid the user could still move to the next step.
    */
    optional?: boolean | string;
    /**
     * Gets/sets whether the step is interactable.
    */
    disabled?: boolean | string;
    /**
     * Gets/sets whether the step is completed.
     * @remarks
     * When set to `true` the following separator is styled `solid`.
    */
    complete?: boolean | string;
    /**
     * @private
    */
    previousComplete?: boolean | string;
    /**
     * @private
    */
    stepType?: StepStepType | string;
    /**
     * @private
    */
    titlePosition?: StepTitlePosition | string;
    /**
     * @private
    */
    orientation?: StepOrientation | string;
    /**
     * @private
    */
    index?: number | string;
    /**
     * @private
    */
    contentTop?: boolean | string;
    /**
     * @private
    */
    linearDisabled?: boolean | string;
    /**
     * @private
    */
    visited?: boolean | string;
}
